@@ -8,5 +8,5 @@ autoheader
 # WORKAROUND: invoke automake (even though we don't use it) to ensure
 # that `install-sh` gets added; this works around a bug in older
 # versions of GNU autotools.
-automake --force-missing --add-missing --copy || :
+automake --force-missing --add-missing --copy >/dev/null 2>&1  || :
 autoconf
